==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Template.pm <==
package WebGUI::i18n::Spanish::Asset_Template;
use utf8;
our $I18N = {
  'Already attached!' => {
    'lastUpdated' => '1259453840',
    'message' => '¡Ya está adjunto!'
  },
  'No url!' => {
    'lastUpdated' => '1259453847',
    'message' => '¡Falta el URL!'
  },
  'assetName' => {
    'lastUpdated' => '1252457577',
    'message' => 'Plantilla'
  },
  'attachment add button' => {
    'lastUpdated' => '1252457596',
    'message' => 'Agregar'
  },
  'attachment add field label' => {
    'lastUpdated' => '1252457605',
    'message' => 'Agregar Adjuntos'
  },
  'attachment display label' => {
    'lastUpdated' => '1252457612',
    'message' => 'Adjuntos'
  },
  'attachment header index' => {
    'lastUpdated' => '1252457631',
    'message' => 'Indice'
  },
  'attachment header remove' => {
    'lastUpdated' => '1252457643',
    'message' => 'Eliminar'
  },
  'attachment header type' => {
    'lastUpdated' => '1252457650',
    'message' => 'Tipo'
  },
  'attachment header url' => {
    'lastUpdated' => '1252457656',
    'message' => 'URL'
  },
  'body background color' => {
    'lastUpdated' => '1252457673',
    'message' => 'Color de Fondo del Body'
  },
  'body background color description' => {
    'lastUpdated' => '1252457684',
    'message' => 'El color de fondo del cuerpo (BODY) de la página.'
  },
  'body content' => {
    'lastUpdated' => '1252457695',
    'message' => 'El contenido del BODY va aquí.'
  },
  'body text color' => {
    'lastUpdated' => '1252457705',
    'message' => 'Color de texto del Body'
  },
  'body text color description' => {
    'lastUpdated' => '1216308893',
    'message' => 'El color del texto en el cuerpo.'
  },
  'choose a layout' => {
    'lastUpdated' => '1252457857',
    'message' => 'Escoja el Layout para este estilo:'
  },
  'css label' => {
    'lastUpdated' => '1252457867',
    'message' => 'Hoja de Estilo (CSS)'
  },
  'default parser' => {
    'lastUpdated' => '1252457959',
    'message' => 'Parser por omisión'
  },
  'edit template' => {
    'lastUpdated' => '1252457968',
    'message' => 'Editar Plantilla'
  },
  'head block' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'head block description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'header background color' => {
    'lastUpdated' => '1252457982',
    'message' => 'Color de Fondo para Encabezado'
  },
  'header background color description' => {
    'lastUpdated' => '1252457995',
    'message' => 'Color de fondo para el encabezado de la página.'
  },
  'header text color' => {
    'lastUpdated' => '1252458007',
    'message' => 'Color de Texto para Encabezado'
  },
  'header text color description' => {
    'lastUpdated' => '1252458034',
    'message' => 'Color para el texto del encabezado.'
  },
  'heading' => {
    'lastUpdated' => '1252458043',
    'message' => 'Encabezado'
  },
  'js body label' => {
    'lastUpdated' => '1252458057',
    'message' => 'JavaScript (Body)'
  },
  'js head label' => {
    'lastUpdated' => '1252458068',
    'message' => 'JavaScript (Encabezado)'
  },
  'link color' => {
    'lastUpdated' => '1252458075',
    'message' => 'Color para Enlaces'
  },
  'link color description' => {
    'lastUpdated' => '1252458090',
    'message' => 'Color para los enlaces en la página. El color por defecto es azul.'
  },
  'logo' => {
    'lastUpdated' => '1252458101',
    'message' => 'Logo'
  },
  'logo description' => {
    'lastUpdated' => '1252458135',
    'message' => 'Use este campo para incluir un logotipo en su estilo. El logotipo debe tener menos de 200 pixels de ancho y menos de 100 pixels de alto.'
  },
  'logo subtext' => {
    'lastUpdated' => '1252458169',
    'message' => 'Menos de 200 pixels de ancho y menos de 100 pixels de alto'
  },
  'make duplicate label' => {
    'lastUpdated' => '1252458193',
    'message' => 'Duplicar Plantilla y Editar'
  },
  'menu' => {
    'lastUpdated' => '1207596804',
    'message' => 'Menu'
  },
  'menu background color' => {
    'lastUpdated' => '1252458206',
    'message' => 'Color de Fondo para Menú'
  },
  'menu background color description' => {
    'lastUpdated' => '1252458216',
    'message' => 'Color de fondo para el menú.'
  },
  'namespace' => {
    'lastUpdated' => '1252458226',
    'message' => 'Espacio de Nombres'
  },
  'namespace description' => {
    'lastUpdated' => '1252458240',
    'message' => '¿Qué tipo de plantilla es ésta?'
  },
  'page background color' => {
    'lastUpdated' => '1252458251',
    'message' => 'Color de Fondo para Página'
  },
  'page background color description' => {
    'lastUpdated' => '1252458261',
    'message' => 'Color de fondo para la página.'
  },
  'parser' => {
    'lastUpdated' => '1252458272',
    'message' => 'Tipo de Plantilla'
  },
  'parser description' => {
    'lastUpdated' => '1252458320',
    'message' => 'Si su archivo de configuración registra múltiples motores de plantillas, seleccione el tipo específico de plantilla a procesar'
  },
  'plugin enabled header' => {
    'lastUpdated' => '1252458335',
    'message' => '¿Habilitado?'
  },
  'plugin name' => {
    'lastUpdated' => '1252458346',
    'message' => 'Procesador'
  },
  'session form variables' => {
    'lastUpdated' => '1252458424',
    'message' => '<strong>Variables de Sesión</strong><br>Puede acceder a cualquiera de las variables de sesión con la sintaxis:<br><br>&lt;tmpl_var session.form.<em>variable</em>&gt;<br><br>Si hay más de un valor para una variable, solamente se obtendrá el <em>último</em>.'
  },
  'session scratch variables' => {
    'lastUpdated' => '1252458466',
    'message' => '<strong>Variables Scratch</strong><br><br>Cualquiera de las variables Scratch es accesible con la sintaxis:<br><br>&lt;tmpl_var session.scratch.<em>variable</em>&gt;'
  },
  'session.config.extrasurl' => {
    'lastUpdated' => '1252458492',
    'message' => 'El URL para el directorio <strong>extras</strong>, tal como aparece en el archivo de configuración de WebGUI.'
  },
  'session.setting.anonymousRegistration' => {
    'lastUpdated' => '1252458524',
    'message' => 'Un condicional que indica si el Registro Anónimo ha sido habilitado o no en la Configuración de WebGUI.'
  },
  'session.setting.companyName' => {
    'lastUpdated' => '1252458543',
    'message' => 'El nombre de la compañía, según se define en la Configuración de WebGUI.'
  },
  'session.user.firstDayOfWeek' => {
    'lastUpdated' => '1252458568',
    'message' => 'El día de inicio de la semana según el perfil del usuario actual.'
  },
  'session.user.username' => {
    'lastUpdated' => '1252458577',
    'message' => 'El nombre del usuario actual.'
  },
  'session.var.adminOn' => {
    'lastUpdated' => '1252458595',
    'message' => 'Un condicional que indica si el usuario ha activado el modo Administrador o no.'
  },
  'show in forms' => {
    'lastUpdated' => '1252458605',
    'message' => '¿Mostrar en Formularios?'
  },
  'show in forms description' => {
    'lastUpdated' => '1252458640',
    'message' => '¿Esta Plantilla debe aparecer en la lista de plantillas disponibles para el Espacio de Nombres particular?'
  },
  'site name' => {
    'lastUpdated' => '1207596827',
    'message' => 'Nombre del Sitio'
  },
  'site name description' => {
    'lastUpdated' => '1252458655',
    'message' => 'El nombre de este sitio Web.'
  },
  'style wizard' => {
    'lastUpdated' => '1252458667',
    'message' => 'Wizard de Estilo'
  },
  'template description' => {
    'lastUpdated' => '1252458699',
    'message' => 'Defina su plantilla empleando una combinación de directivas y variables de plantillas, macros WebGUI y HTML.'
  },
  'template error' => {
    'lastUpdated' => '1255726171',
    'message' => 'Hay un error de sintaxis en la Plantilla, %s, %s, %s.<br>Intente de nuevo después de corregirlo.'
  },
  'template in clipboard' => {
    'lastUpdated' => '1255726182',
    'message' => 'Plantilla en Portapapeles'
  },
  'template in trash' => {
    'lastUpdated' => '1255726190',
    'message' => 'Plantilla en Papelera'
  },
  'template parsers' => {
    'lastUpdated' => '1252458743',
    'message' => 'Procesadores de Plantillas'
  },
  'template parsers list body' => {
    'lastUpdated' => '1252458772',
    'message' => 'Los siguientes procesadores de plantillas están instalados en su servidor y pueden ser habilitados para ser aprovechados por WebGUI.'
  },
  'template parsers list title' => {
    'lastUpdated' => '1252458782',
    'message' => 'Lista de Procesadores de Plantillas'
  },
  'template variable title' => {
    'lastUpdated' => '1252458792',
    'message' => 'Variables de Plantilla'
  },
  'usePacked description' => {
    'lastUpdated' => '1252458816',
    'message' => 'Usar la versión compacta de esta Plantilla para descargas más rápidas.'
  },
  'usePacked label' => {
    'lastUpdated' => '1252458831',
    'message' => '¿Usar Plantilla Compacta?'
  },
  'visited link color' => {
    'lastUpdated' => '1252458843',
    'message' => 'Color para Enlaces Visitados'
  },
  'visited link color description' => {
    'lastUpdated' => '1252458863',
    'message' => 'Color para los enlaces visitados presentes en la página. El color por defectos es morado.'
  },
  'warning default template' => {
    'lastUpdated' => '1252458918',
    'message' => 'Está tratando de editar una Plantilla Estándar. Cualquier cambio efectuado sobre esta Plantilla puede perderse irremediablemente cuando se actualiza WebGUI. Se recomienda duplicar esta Plantilla y trabajar sobre una copia.'
  },
  'webgui.status' => {
    'lastUpdated' => '1252458948',
    'message' => 'El estado de producto de la versión de WebGUI (stable, beta, gamma, etc.)'
  },
  'webgui.version' => {
    'lastUpdated' => '1252458965',
    'message' => 'La versión instalada de WebGUI.'
  }
}
;

1;

==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Template.pm <==
package WebGUI::i18n::Spanish::Asset_Template;
use utf8;
our $I18N = {
  'Already attached!' => {
    'lastUpdated' => '1259453840',
    'message' => '¡Ya está adjunto!'
  },
  'No url!' => {
    'lastUpdated' => '1259453847',
    'message' => '¡Falta el URL!'
  },
  'assetName' => {
    'lastUpdated' => '1252457577',
    'message' => 'Plantilla'
  },
  'attachment add button' => {
    'lastUpdated' => '1252457596',
    'message' => 'Agregar'
  },
  'attachment add field label' => {
    'lastUpdated' => '1252457605',
    'message' => 'Agregar Adjuntos'
  },
  'attachment display label' => {
    'lastUpdated' => '1252457612',
    'message' => 'Adjuntos'
  },
  'attachment header index' => {
    'lastUpdated' => '1252457631',
    'message' => 'Indice'
  },
  'attachment header remove' => {
    'lastUpdated' => '1252457643',
    'message' => 'Eliminar'
  },
  'attachment header type' => {
    'lastUpdated' => '1252457650',
    'message' => 'Tipo'
  },
  'attachment header url' => {
    'lastUpdated' => '1252457656',
    'message' => 'URL'
  },
  'body background color' => {
    'lastUpdated' => '1252457673',
    'message' => 'Color de Fondo del Body'
  },
  'body background color description' => {
    'lastUpdated' => '1252457684',
    'message' => 'El color de fondo del cuerpo (BODY) de la página.'
  },
  'body content' => {
    'lastUpdated' => '1252457695',
    'message' => 'El contenido del BODY va aquí.'
  },
  'body text color' => {
    'lastUpdated' => '1252457705',
    'message' => 'Color de texto del Body'
  },
  'body text color description' => {
    'lastUpdated' => '1216308893',
    'message' => 'El color del texto en el cuerpo.'
  },
  'choose a layout' => {
    'lastUpdated' => '1252457857',
    'message' => 'Escoja el Layout para este estilo:'
  },
  'css label' => {
    'lastUpdated' => '1252457867',
    'message' => 'Hoja de Estilo (CSS)'
  },
  'default parser' => {
    'lastUpdated' => '1252457959',
    'message' => 'Parser por omisión'
  },
  'edit template' => {
    'lastUpdated' => '1252457968',
    'message' => 'Editar Plantilla'
  },
  'field storageIdExample' => {
    'lastUpdated' => '1276812045',
    'message' => 'Imagen de Ejemplo'
  },
  'field storageIdExample description' => {
    'lastUpdated' => '1276812478',
    'message' => 'Una imagen que muestra como se verá la plantilla antes de que sea seleccionada por el usuario.'
  },
  'head block' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'head block description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'header background color' => {
    'lastUpdated' => '1252457982',
    'message' => 'Color de Fondo para Encabezado'
  },
  'header background color description' => {
    'lastUpdated' => '1252457995',
    'message' => 'Color de fondo para el encabezado de la página.'
  },
  'header text color' => {
    'lastUpdated' => '1252458007',
    'message' => 'Color de Texto para Encabezado'
  },
  'header text color description' => {
    'lastUpdated' => '1252458034',
    'message' => 'Color para el texto del encabezado.'
  },
  'heading' => {
    'lastUpdated' => '1252458043',
    'message' => 'Encabezado'
  },
  'js body label' => {
    'lastUpdated' => '1252458057',
    'message' => 'JavaScript (Body)'
  },
  'js head label' => {
    'lastUpdated' => '1252458068',
    'message' => 'JavaScript (Encabezado)'
  },
  'link color' => {
    'lastUpdated' => '1252458075',
    'message' => 'Color para Enlaces'
  },
  'link color description' => {
    'lastUpdated' => '1252458090',
    'message' => 'Color para los enlaces en la página. El color por defecto es azul.'
  },
  'logo' => {
    'lastUpdated' => '1252458101',
    'message' => 'Logo'
  },
  'logo description' => {
    'lastUpdated' => '1252458135',
    'message' => 'Use este campo para incluir un logotipo en su estilo. El logotipo debe tener menos de 200 pixels de ancho y menos de 100 pixels de alto.'
  },
  'logo subtext' => {
    'lastUpdated' => '1252458169',
    'message' => 'Menos de 200 pixels de ancho y menos de 100 pixels de alto'
  },
  'make duplicate label' => {
    'lastUpdated' => '1252458193',
    'message' => 'Duplicar Plantilla y Editar'
  },
  'menu' => {
    'lastUpdated' => '1207596804',
    'message' => 'Menu'
  },
  'menu background color' => {
    'lastUpdated' => '1252458206',
    'message' => 'Color de Fondo para Menú'
  },
  'menu background color description' => {
    'lastUpdated' => '1252458216',
    'message' => 'Color de fondo para el menú.'
  },
  'namespace' => {
    'lastUpdated' => '1252458226',
    'message' => 'Espacio de Nombres'
  },
  'namespace description' => {
    'lastUpdated' => '1252458240',
    'message' => '¿Qué tipo de plantilla es ésta?'
  },
  'page background color' => {
    'lastUpdated' => '1252458251',
    'message' => 'Color de Fondo para Página'
  },
  'page background color description' => {
    'lastUpdated' => '1252458261',
    'message' => 'Color de fondo para la página.'
  },
  'parser' => {
    'lastUpdated' => '1252458272',
    'message' => 'Tipo de Plantilla'
  },
  'parser description' => {
    'lastUpdated' => '1252458320',
    'message' => 'Si su archivo de configuración registra múltiples motores de plantillas, seleccione el tipo específico de plantilla a procesar'
  },
  'plugin enabled header' => {
    'lastUpdated' => '1252458335',
    'message' => '¿Habilitado?'
  },
  'plugin name' => {
    'lastUpdated' => '1252458346',
    'message' => 'Procesador'
  },
  'session form variables' => {
    'lastUpdated' => '1252458424',
    'message' => '<strong>Variables de Sesión</strong><br>Puede acceder a cualquiera de las variables de sesión con la sintaxis:<br><br>&lt;tmpl_var session.form.<em>variable</em>&gt;<br><br>Si hay más de un valor para una variable, solamente se obtendrá el <em>último</em>.'
  },
  'session scratch variables' => {
    'lastUpdated' => '1252458466',
    'message' => '<strong>Variables Scratch</strong><br><br>Cualquiera de las variables Scratch es accesible con la sintaxis:<br><br>&lt;tmpl_var session.scratch.<em>variable</em>&gt;'
  },
  'session.config.extrasurl' => {
    'lastUpdated' => '1252458492',
    'message' => 'El URL para el directorio <strong>extras</strong>, tal como aparece en el archivo de configuración de WebGUI.'
  },
  'session.setting.anonymousRegistration' => {
    'lastUpdated' => '1252458524',
    'message' => 'Un condicional que indica si el Registro Anónimo ha sido habilitado o no en la Configuración de WebGUI.'
  },
  'session.setting.companyName' => {
    'lastUpdated' => '1252458543',
    'message' => 'El nombre de la compañía, según se define en la Configuración de WebGUI.'
  },
  'session.user.firstDayOfWeek' => {
    'lastUpdated' => '1252458568',
    'message' => 'El día de inicio de la semana según el perfil del usuario actual.'
  },
  'session.user.username' => {
    'lastUpdated' => '1252458577',
    'message' => 'El nombre del usuario actual.'
  },
  'session.var.adminOn' => {
    'lastUpdated' => '1252458595',
    'message' => 'Un condicional que indica si el usuario ha activado el modo Administrador o no.'
  },
  'show in forms' => {
    'lastUpdated' => '1252458605',
    'message' => '¿Mostrar en Formularios?'
  },
  'show in forms description' => {
    'lastUpdated' => '1252458640',
    'message' => '¿Esta Plantilla debe aparecer en la lista de plantillas disponibles para el Espacio de Nombres particular?'
  },
  'site name' => {
    'lastUpdated' => '1207596827',
    'message' => 'Nombre del Sitio'
  },
  'site name description' => {
    'lastUpdated' => '1252458655',
    'message' => 'El nombre de este sitio Web.'
  },
  'style wizard' => {
    'lastUpdated' => '1252458667',
    'message' => 'Wizard de Estilo'
  },
  'template description' => {
    'lastUpdated' => '1252458699',
    'message' => 'Defina su plantilla empleando una combinación de directivas y variables de plantillas, macros WebGUI y HTML.'
  },
  'template error' => {
    'lastUpdated' => '1255726171',
    'message' => 'Hay un error de sintaxis en la Plantilla, %s, %s, %s.<br>Intente de nuevo después de corregirlo.'
  },
  'template in clipboard' => {
    'lastUpdated' => '1255726182',
    'message' => 'Plantilla en Portapapeles'
  },
  'template in trash' => {
    'lastUpdated' => '1255726190',
    'message' => 'Plantilla en Papelera'
  },
  'template parsers' => {
    'lastUpdated' => '1252458743',
    'message' => 'Procesadores de Plantillas'
  },
  'template parsers list body' => {
    'lastUpdated' => '1252458772',
    'message' => 'Los siguientes procesadores de plantillas están instalados en su servidor y pueden ser habilitados para ser aprovechados por WebGUI.'
  },
  'template parsers list title' => {
    'lastUpdated' => '1252458782',
    'message' => 'Lista de Procesadores de Plantillas'
  },
  'template variable title' => {
    'lastUpdated' => '1252458792',
    'message' => 'Variables de Plantilla'
  },
  'usePacked description' => {
    'lastUpdated' => '1252458816',
    'message' => 'Usar la versión compacta de esta Plantilla para descargas más rápidas.'
  },
  'usePacked label' => {
    'lastUpdated' => '1252458831',
    'message' => '¿Usar Plantilla Compacta?'
  },
  'visited link color' => {
    'lastUpdated' => '1252458843',
    'message' => 'Color para Enlaces Visitados'
  },
  'visited link color description' => {
    'lastUpdated' => '1252458863',
    'message' => 'Color para los enlaces visitados presentes en la página. El color por defectos es morado.'
  },
  'warning default template' => {
    'lastUpdated' => '1252458918',
    'message' => 'Está tratando de editar una Plantilla Estándar. Cualquier cambio efectuado sobre esta Plantilla puede perderse irremediablemente cuando se actualiza WebGUI. Se recomienda duplicar esta Plantilla y trabajar sobre una copia.'
  },
  'webgui.status' => {
    'lastUpdated' => '1252458948',
    'message' => 'El estado de producto de la versión de WebGUI (stable, beta, gamma, etc.)'
  },
  'webgui.version' => {
    'lastUpdated' => '1252458965',
    'message' => 'La versión instalada de WebGUI.'
  }
}
;

1;
